==> wiki3_4_3.zip: wiki3_4_3/plugin/bugtrack/BugTrack.pm <==
################################################################################
#
# ХݡȤƤ뤿Υեɽޤ
# Ȥƥץ̾ӥХΥƥꤷޤ
# <pre>
# {{bugtrack ץ̾,ƥ꣱,ƥꣲ...}}
# </pre>
# ΥեफХݡȤƤ
# <pre>
#  BugTrack-ץ̾/ֹ
# </pre>
# Ȥ̾Υڡޤ
# ϿѤߤΥХݡȤξ֤ѹϡХݡȤľԽ
# ֤ơססִλס֥꡼ѡסαסֵѲפΤ줫
# 񤭴Ƥ
# 
################################################################################
package plugin::bugtrack::BugTrack;
#use strict;
#===============================================================================
# 󥹥ȥ饯
#===============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===============================================================================
# 饤ץ饰Υ᥽å
#===============================================================================
sub inline {
	my $self     = shift;
	my $wiki     = shift;
	my $project  = shift;
	my @category = @_;
	my $cgi      = $wiki->get_CGI();
	
	if($project eq ""){
		return "<font class=\"error\">ץ̾ꤵƤޤ</font>";
	}
	if($#category == -1){
		return "<font class=\"error\">ƥ꤬ꤵƤޤ</font>";
	}
	
	my $template = HTML::Template->new(filename=>$wiki->config('tmpl_dir')."/bugtrack.tmpl",
	                                   die_on_bad_params => 0);
	
	my @priority = ("۵","","","");
	my @status   = ("","","λ","꡼","α","Ѳ");
	
	$template->param(PRIORITY => &make_array_ref(@priority));
	$template->param(STATUS   => &make_array_ref(@status));
	$template->param(CATEGORY => &make_array_ref(@category));
	
	# ̾
	my $name = $cgi->cookie(-name=>'post_name');
	if($name eq ''){
		my $login = $wiki->get_login_info();
		if(defined($login)){
			$name = $login->{id};
		}
	}
	$template->param(NAME=>$name);
	
	my $buf = "<form action=\"".$wiki->config('script_name')."\" method=\"post\">\n".
	          $template->output().
	          "<input type=\"hidden\" name=\"action\" value=\"BUG_POST\">\n".
	          "<input type=\"hidden\" name=\"project\" value=\"".&Util::escapeHTML($project)."\">\n".
	          "</form>\n";
	
	return $buf;
}

#===============================================================================
# ܤե󥹤
#===============================================================================
sub make_array_ref {
	my @array    = @_;
	my $arrayref = [];
	foreach(@array){
		push(@$arrayref,{NAME=>$_,VALUE=>$_});
	}
	return $arrayref;
}


1;

==> wiki3_5_0.zip: wiki3_5_0/plugin/bugtrack/BugTrack.pm <==
################################################################################
#
# ХݡȤƤ뤿Υեɽޤ
# Ȥƥץ̾ӥХΥƥꤷޤ
# <pre>
# {{bugtrack ץ̾,ƥ꣱,ƥꣲ...}}
# </pre>
# ΥեफХݡȤƤ
# <pre>
#  BugTrack-ץ̾/ֹ
# </pre>
# Ȥ̾Υڡޤ
# ϿѤߤΥХݡȤξ֤ѹϡХݡȤľԽ
# ֤ơססִλס֥꡼ѡסαסֵѲפΤ줫
# 񤭴Ƥ
# 
################################################################################
package plugin::bugtrack::BugTrack;
#use strict;
#===============================================================================
# 󥹥ȥ饯
#===============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===============================================================================
# ѥ饰
#===============================================================================
sub paragraph {
	my $self     = shift;
	my $wiki     = shift;
	my $project  = shift;
	my @category = @_;
	my $cgi      = $wiki->get_CGI();
	
	if($project eq ""){
		return &Util::paragraph_error("ץ̾ꤵƤޤ");
	}
	if($#category == -1){
		return &Util::paragraph_error("ƥ꤬ꤵƤޤ");
	}
	
	my $template = HTML::Template->new(filename=>$wiki->config('tmpl_dir')."/bugtrack.tmpl",
	                                   die_on_bad_params => 0);
	
	my @priority = ("۵","","","");
	my @status   = ("","","λ","꡼","α","Ѳ");
	
	$template->param(PRIORITY => &make_array_ref(@priority));
	$template->param(STATUS   => &make_array_ref(@status));
	$template->param(CATEGORY => &make_array_ref(@category));
	
	# ̾
	my $name = $cgi->cookie(-name=>'post_name');
	if($name eq ''){
		my $login = $wiki->get_login_info();
		if(defined($login)){
			$name = $login->{id};
		}
	}
	$template->param(NAME=>$name);
	
	my $buf = "<form action=\"".$wiki->config('script_name')."\" method=\"post\">\n".
	          $template->output().
	          "<input type=\"hidden\" name=\"action\" value=\"BUG_POST\">\n".
	          "<input type=\"hidden\" name=\"project\" value=\"".&Util::escapeHTML($project)."\">\n".
	          "</form>\n";
	
	return $buf;
}

#===============================================================================
# ܤե󥹤
#===============================================================================
sub make_array_ref {
	my @array    = @_;
	my $arrayref = [];
	foreach(@array){
		push(@$arrayref,{NAME=>$_,VALUE=>$_});
	}
	return $arrayref;
}


1;
